@@ -1,11 +1,14 @@
+# flake8: noqa
 import easypost.beta
 from easypost.address import Address
+from easypost.api_key import ApiKey
 from easypost.batch import Batch
 from easypost.billing import Billing
 from easypost.brand import Brand
 from easypost.carrier_account import CarrierAccount
 from easypost.customs_info import CustomsInfo
 from easypost.customs_item import CustomsItem
+from easypost.endshipper import EndShipper
 from easypost.error import Error
 from easypost.event import Event
 from easypost.insurance import Insurance
@@ -15,6 +18,7 @@ from easypost.pickup import Pickup
 from easypost.pickup_rate import PickupRate
 from easypost.postage_label import PostageLabel
 from easypost.rate import Rate
+from easypost.referral import Referral
 from easypost.refund import Refund
 from easypost.report import Report
 from easypost.scanform import ScanForm
