@@ -2,13 +2,10 @@ import json
 
 import easypost
 from easypost.easypost_object import convert_to_easypost_object
-from easypost.resource import (
-    AllResource,
-    Resource,
-)
+from easypost.resource import AllResource
 
 
-class Event(AllResource, Resource):
+class Event(AllResource):
     @classmethod
     def receive(cls, values: str) -> "Event":
         return convert_to_easypost_object(response=json.loads(s=values), api_key=easypost.api_key)
